summaryrefslogtreecommitdiffstats
path: root/src/projectmanager.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:57:14 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:57:14 -0600
commitc1ef065782051db96cdfd32cf55be6408c2a9d22 (patch)
tree0bc3705b597f8c98b2b9992d22ab9620df50b877 /src/projectmanager.h
parentbab171b2a7d7f36e2d5dd510df80fc8cb4a6b06f (diff)
downloadktechlab-c1ef065782051db96cdfd32cf55be6408c2a9d22.tar.gz
ktechlab-c1ef065782051db96cdfd32cf55be6408c2a9d22.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit bab171b2a7d7f36e2d5dd510df80fc8cb4a6b06f.
Diffstat (limited to 'src/projectmanager.h')
-rw-r--r--src/projectmanager.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/projectmanager.h b/src/projectmanager.h
index 54f873f..33d239b 100644
--- a/src/projectmanager.h
+++ b/src/projectmanager.h
@@ -160,11 +160,11 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
void setILVItem( ILVItem * ilvItem );
/**
* Adds the child to the list of children, and creates an ILVItem for it
* in the project tree view.
*/
void addChild( ProjectItem * child );
- ProjectItemList children() const { return m_children; }
+ ProjectItemList tqchildren() const { return m_tqchildren; }
void setName( const TQString & name );
TQString name() const { return m_name; }
@@ -180,12 +180,12 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
OutputType outputType() const;
/**
* Returns a list of output urls of the children and their recursively
* contained children (does not include the url for this project item).
* @param types An OR'ed list of ProjectItem::Type values for the
- * children.
+ * tqchildren.
* @param outputTypes An OR'ed list of ProjectItem::OutputType values
- * for the children.
+ * for the tqchildren.
*/
KURL::List childOutputURLs( unsigned types = AllTypes, unsigned outputTypes = AllOutputs ) const;
@@ -210,7 +210,7 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
virtual TQString microID() const;
/**
* Searches this item and the children for an item for the given url,
* return null if no such item could be found.
*/
ProjectItem * findItem( const KURL & url );
@@ -222,7 +222,7 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
KURL m_url;
TQString m_name;
- ProjectItemList m_children;
+ ProjectItemList m_tqchildren;
Type m_type;
KTechlab * p_ktechlab;
@@ -160,11 +160,11 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
void setILVItem( ILVItem * ilvItem );
/**
- * Adds the child to the list of children, and creates an ILVItem for it
+ * Adds the child to the list of tqchildren, and creates an ILVItem for it
* in the project tree view.
*/
@@ -180,12 +180,12 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
OutputType outputType() const;
/**
- * Returns a list of output urls of the children and their recursively
- * contained children (does not include the url for this project item).
+ * Returns a list of output urls of the tqchildren and their recursively
+ * contained tqchildren (does not include the url for this project item).
* @param types An OR'ed list of ProjectItem::Type values for the
@@ -210,7 +210,7 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
virtual TQString microID() const;
/**
- * Searches this item and the children for an item for the given url,
+ * Searches this item and the tqchildren for an item for the given url,
* return null if no such item could be found.
*/